pycocoa.deprecated.module_property_RO

Package pycocoa :: Module deprecated :: Class module_property_RO |
[frames] | no frames]

# Class module_property_RO

            object --+
                     |
    internals.proxy_RO --+
                         |
                        module_property_RO

DEPRECATED on 2025.02.09, use `proxy_RO`.

Instance Methods
Inherited from `internals.proxy_RO`: `__getattr__`, `__getitem__`, `__init__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `object`: `__class__`